Crate recall_fendermint_actor_bucket

Crate recall_fendermint_actor_bucket 

Structs

AddParams
Params for adding an object.
DeleteParams
Params for deleting an object.
GetParams
Params for getting an object.
ListObjectsReturn
A list of objects and their common prefixes.
ListParams
Params for listing objects.
Object
The stored representation of an object in the bucket.
ObjectState
The stored representation of an object in the bucket.
State
The state represents a bucket backed by a Hamt.
UpdateObjectMetadataParams

Enums

Method

Constants

BUCKET_ACTOR_NAME
MAX_METADATA_ENTRIES
MAX_METADATA_KEY_SIZE
MAX_METADATA_VALUE_SIZE