Structs
- AddParams
- Params for adding an object.
- Delete
Params - Params for deleting an object.
- GetParams
- Params for getting an object.
- List
Objects Return - A list of objects and their common prefixes.
- List
Params - Params for listing objects.
- Object
- The stored representation of an object in the bucket.
- Object
State - The stored representation of an object in the bucket.
- State
- The state represents a bucket backed by a Hamt.
- Update
Object Metadata Params